@@ -7,11 +7,11 @@ EXECUTABLE_RE = rb'(?i)\b\w+[.]exe\b'
 LIBRARY_RE = rb'(?i)\b\w+[.]dll\b'
 
 
-@analyzer('filename.executable')
+@analyzer('executable.filename')
 def find_executable_name(data: bytes) -> list[Hit]:
     return regex_hits(EXECUTABLE_RE, data)
 
 
-@analyzer('filename.library')
+@analyzer('executable.library.filename')
 def find_library(data: bytes) -> list[Hit]:
     return regex_hits(LIBRARY_RE, data)
